pub trait BundleKind {
const HANDLER: &'static str;
const FORMAT: &'static str;
const WRITABLE: bool;
// Required methods
fn describe_member(path: &str) -> Option<MemberDescription>;
fn is_bundle_name(file_name: &str) -> bool;
}Expand description
The three things that differ between one bundle handler and another.
Required Associated Constants
Required Methods
Sourcefn describe_member(path: &str) -> Option<MemberDescription>
fn describe_member(path: &str) -> Option<MemberDescription>
Classify one bundle-relative path. None = not a member of this kind of
bundle, which the handler reports as a 404 rather than guessing.
Sourcefn is_bundle_name(file_name: &str) -> bool
fn is_bundle_name(file_name: &str) -> bool
Does this bare filename look like one of this kind’s sealed bundles? Used to filter a store listing that may hold other files.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".